summaryrefslogtreecommitdiffstats
path: root/kmix/viewswitches.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:07 -0600
commit3c299dfe48c0060272c2966fff599b3b417e2ee4 (patch)
treef248b71f55539d6689a4cbe086d5d8cc146c8998 /kmix/viewswitches.cpp
parentf59dfa08651a47f21d004e8e4cb5020b8035287e (diff)
downloadtdemultimedia-3c299dfe48c0060272c2966fff599b3b417e2ee4.tar.gz
tdemultimedia-3c299dfe48c0060272c2966fff599b3b417e2ee4.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kmix/viewswitches.cpp')
-rw-r--r--kmix/viewswitches.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmix/viewswitches.cpp b/kmix/viewswitches.cpp
index 3d3166bb..3c414815 100644
--- a/kmix/viewswitches.cpp
+++ b/kmix/viewswitches.cpp
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// Place enums right from the switches: This is done, so that there will be no
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
// the _layoutEnum, so it might be a tqsizeHint() or some other subtle tqlayout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}
init();
@@ -118,9 +118,9 @@ TQWidget* ViewSwitches::add(MixDevice *md)
return mdw;
}
-TQSize ViewSwitches::tqsizeHint() const {
- //kdDebug(67100) << "ViewSwitches::tqsizeHint(): NewSize is " << _layoutMDW->tqsizeHint() << "\n";
- return( _layoutMDW->tqsizeHint() );
+TQSize ViewSwitches::sizeHint() const {
+ //kdDebug(67100) << "ViewSwitches::sizeHint(): NewSize is " << _layoutMDW->sizeHint() << "\n";
+ return( _layoutMDW->sizeHint() );
}
void ViewSwitches::constructionFinished() {
@@ -46,7 +46,7 @@ ViewSwitches::ViewSwitches(TQWidget* parent, const char* name, const TQString &
// ugly space on the left side, when no Switch is shown.
// Actually it is not really clear yet, why there is empty space at all: There are 0 items in
- // the _layoutEnum, so it might be a tqsizeHint() or some other subtle tqlayout issue.
+ // the _layoutEnum, so it might be a sizeHint() or some other subtle tqlayout issue.
_layoutEnum = new TQVBoxLayout(_layoutMDW);
}